#!/usr/bin/python3

# Author: vcorreal (victor.correal@bsc.es)
# Date  : 19-12-2023 
# For documentation see the main method

import argparse
from parsing import *


def main():
    #Argument parsing
    parser = argparse.ArgumentParser(description="Get SDPD")
    parser.add_argument('--output_dirs', required=False, help="Input files")
    parser.add_argument('--fclen_d', help="Forecast lenght (in days)")
    parser.add_argument('--fclen_h', help="Forecast lenght (in hours)")
    parser.add_argument('--fclen_s', help="Forecast lenght (in seconds)")
    parser.add_argument('--nodefile', help="Path to node file")
    #parser.add_argument('--resolutions', help="Resolution to find", nargs='+')
    args=parser.parse_args()

    outputs_dir : str = args.output_dirs
    fclen_d : float = args.fclen_d
    fclen_h : float = args.fclen_h
    fclen_s : float = args.fclen_s
    node_file : str = args.nodefile
    #resolutions = args.resolutions TODO: Pass resolutions to the parser

    # USE CASE 1) Compute FCdays from the node file
    if fclen_s is not None and node_file is not None:
        fclen_s = float(fclen_s)
        print(
            round(compute_fc_days_from_cnt4(node_file, fclen_s),
                2
            )
        )

    elif fclen_h is not None and node_file is not None:
        fclen_h = float(fclen_h)
        
        print(
            round(compute_fc_days_from_cnt4(node_file, fclen_h*3600),
                2
            )
        )

    elif fclen_d is not None and node_file is not None:
        fclen_d = float(fclen_d)
        
        print(
            round(compute_fc_days_from_cnt4(node_file, fclen_d*24*3600),
                2
            )
        )

    # USE CASE 2) Compute FCdays for a group of executions
    elif outputs_dir is not None:
        parse_output_dir(outputs_dir)
    
    else:
        print("Warning! Nothing to do :(")
        exit(1)

if __name__ == "__main__":
    main()
    exit(0)
